.. IVLE - Informatics Virtual Learning Environment
   Copyright (C) 2007-2010 The University of Melbourne

.. This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

.. This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

.. You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

.. _ivle-tour:

**************
A tour of IVLE
**************

This page is designed to give a brief overview of IVLE, from a users point of
view (including administrator and lecturer users). Here we assume that you
have :ref:`set up a fresh copy of IVLE <ref-install>` and :ref:`installed the
sample data <sample-data>`. This page refers to the sample data specifically.
If you are just using an existing installation of IVLE, it might still make a
bit of sense, but your mileage may vary.

We will take the tour in three stages: first as a student, then as a lecturer,
and finally as an administrator.

A student's view
================

Begin by logging into IVLE as a student (username: 'studenta', password:
'password').

Files
-----

You will see the IVLE home screen, which displays the subjects you are
enrolled in, and your files for each subject. Along the top is the blue bar
which is always visible in IVLE. Clicking the IVLE logo always returns you to
the home screen.

The user "studenta" is enrolled in several subjects, and has several files
already in her Subversion repository, but they aren't immediately accessible.

First, click all of the "Checkout" buttons, to check out the Subversion
repositories. Now you can explore the sample files, for example, in the
"stuff" directory.

Go into the "stuff" directory and left-click the file "hello.py". This will
open the build-in text editor, which lets you modify the file. Along the top,
there is a button marked "Serve". Clicking this will *run* the Python code as
a CGI application -- this should open a new window which reads "Hello,
world!". You can also click "Run", which will run the program in the built-in
Python console (which pops up from the bottom of the screen). This will be
much uglier, printing the CGI output.

* "Serve" runs Python programs as CGI applications, showing their web output.
* "Run" runs Python programs as command-line applications.

Note that you can also use the console at the bottom of the screen as a
generic Python console, whenever you wish.

You can also serve other files, such as HTML files (try "Welcome to
IVLE.html"). This will just present them as normal web pages.

Files also have full Subversion histories. If you click on a file in the file
view (such as "hello.py"), and go to More Actions -> Subversion -> View Log,
you will see the history of a file, and be able to "select" then view a "diff"
of the file. If you edit a file, you need to commit it (More Actions ->
Subversion -> Commit). If you create a new file (More Actions -> Directory
actions -> New file), you need to add it (More Actions -> Subversion -> Add),
then commit.

Submissions
-----------

This student has already completed a project, and is ready to submit it. Go
into the Intermediate Ivle -> mywork directory. Select "phase1.html" and
choose More Actions -> Publishing -> Submit. This takes you to the Submit
Project screen.

Choose to submit to Phase 1, and click Submit Project.

If you go into the Intermediate Ivle -> group1 directory, you will be able to
make a group submission to Phase 2 (which is a group project). Note that the
Phase 3 submission has already closed.
Also note that the file here ("phase2.html") was edited by studenta and
studentb collaboratively, as you can see in the project's revision log.

Worksheets
----------

Click on Intermediate Ivle -> Subject Home from the home screen (or, from the
IVLE pulldown menu, choose Subjects and select Intermediate Ivle). There is
one worksheet, Worksheet Basics. Clicking this takes you to the worksheet,
where students are challenged by Python questions.

After reading the worksheet, attempt the simple programming question, which is
to write a factorial program.

A sample solution follows::

 def fac(n):
     if n == 0:
         return 1
     else:
         return n * fac(n-1)
 
 def main():
     f = int(raw_input())
     print fac(f)

First, click Submit, and note that the system automatically runs some test
cases, all of which fail. Now paste the solution to :func:`fac` (but not
:func:`main`). Clicking Submit again shows some test cases pass, but not all.
Finally, paste the solution to :func:`main`, and click Submit again. This
time, you will pass the test.

Note that you can also click "Run", and it will execute your solution in the
Python console. This doesn't cost you an "attempt", nor does it run the test
cases. It just lets you test it out for yourself before making an official
submission.

Back on the subject page, you will notice that the exercise appears complete,
and you have been awarded some marks.

A lecturer's view
=================

Log into IVLE as a lecturer (username: 'lecturer', password: 'password'). Many
of these things are also possible as a tutor (try username: 'tutor', password:
'password').

Being a lecturer or tutor is a per-subject privilege, so it only applies to
certain subjects. All of your special powers are under the subject home for
the subjects you are a tutor in. Note that everything a lecturer can do, an
admin can also do, for all subjects in the system.

Click "Intermediate IVLE - Subject home". From here, you will see largely the
same view as a student, but with more buttons. "Change details" allows you to
modify the subject properties. "Enrol users" allows you to add existing IVLE
users as students or tutors of the subject you are teaching (this is currently
an irreversible action).

Managing projects
-----------------

Click "Manage projects" to go to the project management screen. Note that the
3 projects are grouped into "Solo projects" (projects submitted by each
individual student) and "Group projects". Try adding a new Solo project, by
clicking on "Add a new project" within that box. The fields should be fairly
self-explanatory.

.. warning::
   You can't currently edit or delete a project after it has been created.

Group projects are complicated by what we call "project sets". A "project set"
is a set of group projects where the student groups are the same throughout.
For instance, you will see Phase 2 and Phase 3 inside the same project set
box. This means students will get into groups of 3 to submit Phase 2, and then
the same group will submit Phase 3.

Clicking "Manage groups" lets you put students into groups for a given project
set.

Click "Add a new project set" and enter a group size of 6. Then, create a
project in the new set. Each student must get into a new group for each
project *set*. Note also that the groups will share a Subversion repository
for all projects in a set, but if you create a new set, the students will have
to start using a new repository.

Usually, the hassle of getting into new groups and creating new repositories
means that you will want to create a single project set for a subject, and
just partition the projects into solo and group projects.

Managing worksheets and exercises
---------------------------------

Return to the subject home page. Click "Manage worksheets". On this page, you
will see all of the worksheets for the subject. Here you can edit worksheets,
add new ones, and re-order them. You can also edit any worksheet from its own
page.

To get an idea of what a worksheet looks like in edit mode, click the edit
action (pencil) next to "Worksheet Basics".

* The "URL name" is the name of the worksheet as it appears in URLs.
* The "Assessable" checkbox will make the exercises in the worksheet count
  towards each student's worksheet mark, if checked. Uncheck it for
  informational worksheets.
* The "Format" selection controls the format used to write the worksheet in
  the box below. Leave it on "reStructuredText" unless you have a reason not
  to.

Now, you can edit the worksheet content in reStructuredText. The existing text
briefly explains this format. See `A ReStruecturedText Primer
<http://docutils.sourceforge.net/docs/user/rst/quickstart.html>`_ for a full
guide. Note that the exercises themselves are not in the worksheet. They are
separate resources, which can be shared across subjects. Exercises can be
embedded with a line like this::

 .. exercise:: factorial

Click "Manage exercises" to see the exercises (in the sample data, just
"factorial"). An exercise is a very complex thing, due to the fact that it
runs automated testing on the student code. The details are outside the scope
of this tour. Hopefully, you can figure out how they work by examining the
existing "factorial" exercise.

If you are game enough, create a new worksheet from scratch. If you are
*really* game, create a new exercise for your worksheet.

An administrator's view
=======================

Log into IVLE as an admin (username: 'admin', password: 'password').

Administrator users in IVLE have significant privileges. Note, however, that
for technical reasons, admins cannot read or write other users' files. This
requires root access on the machine IVLE is installed on.

Firstly, pull down the IVLE menu (top-left). There is an additional item for
admins -- the "Users" page. This lists all users with an account in IVLE.
Clicking on a username takes you to the user's profile page. Try it with the
user 'lecturer'.

The profile page is exactly the same as the user himself would see it, but
with a few more buttons on the side. "Change password" is the same as the
user's own "Change password" page. However, "Reset password" is a special
admin page which lets you change a user's password without knowing the old
one. "Administer user" also lets you change administrative settings for the
user, such as their full name (more formal than display name, which the user
themselves can change) and student ID. You can also add or remove admin status
for any user.

.. warning::
   Use this with care. Making a user an admin gives them complete control over
   the system. They could even revoke *your* admin rights!

Firstly, note that admin users enjoy the same privileges as lecturers, for all
subjects on the system.

If you go to the 

* Edit any user, reset password.
* Enrol lecturers in a subject.

Admin scripts
-------------

Unfortunately, there are still a few tasks which admins need to do which
haven't been implemented in the UI for the IVLE web application. These tasks
are available as command-line scripts which can be run by someone with root
access on the machine IVLE is installed on. They are gradually being migrated
over to proper UI features in IVLE itself.

Details on these scripts can be found in :ref:`ref-admin-scripts`.
